<?php
  mb_internal_encoding('UTF-8');

  ini_set('display_errors', '0');



  /* --- PHP MULTIBYTE KÓDOVÁNÍ --- */
  /** Multibyte kódování pro PHP funkce pracující s řetězci. */
  define('PHP_MULTIBYTE_ENCODING', 'utf-8');



  /* --- PŘIPOJENÍ K DATABÁZI --- */
  /** PDO řetězec sloužící pro připojení k databázi (včetně hostitele a názvu databáze). */
  define('DB_PDO_DSN', '');

  /** Uživatelské jméno pro přístup do databáze. */
  define('DB_USERNAME', '');

  /** Heslo pro přístup do databáze. */
  define('DB_PASSWORD', '');

  /** Kódování použité při práci s databází. */
  define('DB_ENCODING', 'utf8');



  /* --- PŘIPOJENÍ K LDAP --- */
  /** Hostitel LDAP. */
  define('LDAP_HOSTNAME', 'ldaps://ldap.zcu.cz');

  /** Port k připojení k LDAP. */
  define('LDAP_PORT', 636);

  /** Základní cesta v LDAP. */
  define('LDAP_BASE_DN', 'ou=rfc2307,o=zcu,c=cz');



  /* --- INFORMACE O BEZPEČNOSTNÍM TÝMU --- */
  /** Zkratka bezpečnostního týmu. */
  define('CSIRT_ABRR', 'WIRT');

  /** Název bezpečnostního týmu. */
  define('CSIRT_NAME', 'WEBnet Incident Response Team');

  /** E-mailový kontakt na bezpečnostní tým. */
  define('CSIRT_ABUSE_CONTACT', 'abuse@zcu.cz');

  /** Odkaz na web bezpečnostního týmu. */
  define('CSIRT_URL', 'https://wirt.zcu.cz');

  /** IP rozsah sítě, kterou má bezpečnostní tým ve správě. */
  define('IP_ORG_RANGE', '147.228.0.0/16');

  /** První IP adresa v počítačové síti, kterou má bezpečnostní tým ve správě. */
  define('IP_ORG_START', '147.228.0.0');

  /** Poslední IP adresa v počítačové síti, kterou má bezpečnostní tým ve správě. */
  define('IP_ORG_END', '147.228.255.255');

  /** Doména organizace (bez www), pod kterou mají uživatelé hostovány e-maily. */
  define('ORG_DOMAIN', 'zcu.cz');



  /* --- DALŠÍ NASTAVENÍ --- */
  /** Časové pásmo, do něhož se mají převést uživatelem zadaná data, na základě kterých se bude vyhledávat v logu. */
  define('LOG_TIME_ZONE', 'Europe/Prague');

  /** Název fronty v RT (Request Tracker) systému, ve kterém se budou vytvářet nové lístky (tickety) při zakládání incidentu. */
  define('RT_DEFAULT_QUEUE', 'security');

  /** Adresářová cesta k privátnímu klíči kvůli autorizaci u služeb, které jsou za SSO (WebAuth).
   *  U souboru musí být nastaven chmod 0644 (pro možnost čtení PHP skriptem). */
  define('SSO_FILEPATH_PRIVATE_KEY', '/var/www/blockator.zcu.cz/certificates/servisni-konto.key.pem');

  /** Adresářová cesta k veřejnému klíči kvůli autorizaci u služeb, které jsou za SSO (WebAuth).
   *  U souboru musí být nastaven chmod 0644 (pro možnost čtení PHP skriptem). */
  define('SSO_FILEPATH_PUBLIC_KEY', '/var/www/blockator.zcu.cz/certificates/servisni-konto.crt.pem');



  /* --- LOGOVÁNÍ --- */
  /** Cesta a název souboru, do kterého se budou zapisovat všechny zaznamenané události. Pokud soubor nebude existovat,
  systém jej vytvoří. Záznamy se přidávají atomicky.
   *  U souboru musí být nastaven chmod 0777 (pro možnost čtení a zápisu PHP skriptem). */
  define('LOGGER_FILEPATH', '/var/www/blockator.zcu.cz/log.log');

  /** Formát data, které se bude zapisovat u každé zaznamenané události do protokolu. */
  define('LOGGER_DATE_FORMAT', 'Y-m-d H:i:s');

  /** Úroveň události, od které se budou záznamy ukládat do protokolu, v pořadí: DEBUG < INFO < WARNING < ERROR. */
  define('LOGGER_LEVEL', 'DEBUG');



  /* --- NASTAVENÍ WEBU --- */
  /** Základní nadpis v hlavičce webu. */
  define('WEB_HTML_BASE_TITLE', 'Blockator');

  /** Verze systému. */
  define('WEB_VERSION', '0.1');

  /** URL, na které systém běží (slouží pro přesměrování v rámci systému). */
  define('WEB_URL', 'https://blockator.zcu.cz');



  /* --- ADRESÁŘOVÁ STRUKTURA SYSTÉMU --- */
  /** Hlavní adresář, od kterého se budou odvíjet další adresáře. */
  define('CORE_DOCUMENT_ROOT', '/var/www/blockator.zcu.cz');

  /** Adresář obsahující soubory controllers (kontrolerů). */
  define('CORE_DIR_CONTROLLERS', 'controllers');

  /** Adresář obsahující soubory models (modelů). */
  define('CORE_DIR_MODELS', 'models');

  /** Adresář obsahující soubory blokátorů pro jednotlivé části sítě. */
  define('CORE_DIR_BLOCKERS', 'network-blockers');

  /** Adresář obsahující soubory views (pohledů). */
  define('CORE_DIR_VIEWS', 'views');

  /** Adresář obsahující další dodatečné knihovny. */
  define('CORE_DIR_EXTENSIONS', 'extensions');

  /** Přípona view souborů. */
  define('CORE_VIEWS_FILE_EXTENSION', '.php');



  /* --- CROSS-SITE REQUEST FORGERY --- */
  /** Klíč přidávaný ke generovanému CSRF tokenu. Pro každou instalaci by měl být unikátní (libovolný řetězec). */
  define('CSRF_KEY', '');



  /* --- CONTENT SECURITY POLICY --- */
  /** Hodnota nonce pro Content Security Policy u inline JavaScriptu.
   *  Povolením dojde k zablokování jakéhokoliv JavaScriptu, který není opatřen nonce. */
  define('HTTP_HEADER_CSP_NONCE', base64_encode(openssl_random_pseudo_bytes(32)));



  /* --- PROMĚNNÉ POUŽÍVANÉ V ŠABLONÁCH PRO E-MAILY --- */
  /** Jméno a příjmení uživatele, který je spojen s bezpečnostním incidentem. */
  define('VAR_INCIDENT_USER', '%incident_user%');

  /** Označení (název) sítě, ve které k bezpečnostnímu incidentu došlo. */
  define('VAR_INCIDENT_NETWORK', '%incident_network%');

  /** Název bezpečnostního týmu. */
  define('VAR_CSIRT_NAME', '%csirt_name%');

  /** Jméno a příjmení člena bezpečnostního týmu, který incident řeší. */
  define('VAR_CSIRT_MEMBER_NAME', '%csirt_member_name%');



  /* --- ŘEŠENÍ INCIDENTU --- */
  /** Identifikátor posledního kroku (stav "vyřešeno") při řešení bezpečnostního incidentu. */
  define('INCIDENT_FINAL_STEP_ID', 6);

  /** Oddělovač mezi zprávami různých jazykových mutací. */
  define('INCIDENT_MESSAGE_BODY_DELIM', "\n\n------------------------------------\n\n");

  /** Oddělovač mezi předměty různých jazykových mutací. */
  define('INCIDENT_MESSAGE_SUBJECT_DELIM', ' / ');

  /** Výchozí jazyk u šablon pro e-maily určených pro uživatele (každý jazyk oddělen čárkou). */
  define('INCIDENT_USER_DEFAULT_LANG', 'cz');

  /** Výchozí jazyk u šablon pro e-maily určených pro stěžovatele (každý jazyk oddělen čárkou). */
  define('INCIDENT_COMPLAINANT_DEFAULT_LANG', 'cz');



  /* --- KÓDY HLÁŠEK --- */
  /* Názvy hlášek a jejich přiřazení k Exception->getCode() používaných ve zdrojovém kódu. */

  /** Chyba. */
  define('MSG_ERROR', 1);

  /** Úspěch. */
  define('MSG_SUCCESS', 2);

  /** Varování. */
  define('MSG_WARNING', 3);



  /* --- URL AKCÍ POUŽÍVANÝCH VE ZDROJOVÉM KÓDU --- */
  /** Vytvoření nového záznamu. */
  define('ACT_NEW', 'new');

  /** Úprava existujícího záznamu. */
  define('ACT_EDIT', 'edit');

  /** Smazání záznamu. */
  define('ACT_DEL', 'delete');

  /** Vymazání dat ve formuláři. */
  define('ACT_RESET', 'reset-form');