<?php
  /**
   * Třída zpracovává uživatelský vstup úvodní stránky, na základě kterého volá
   * odpovídající metody, přičemž svůj výstup předává další vrstvě pro výpis.
   *
   * @author Martin Šebela
   */
  class DashboardController extends Controller {
    /**
     * Zpracuje vstup z URL adresy a na základě toho zavolá odpovídající metodu.
     *
     * @param array $arguments         Uživatelský vstup.
     */
    public function process($arguments) {
      $this->setTitle('Úvodní stránka');
      $this->setView('homepage');

      // Získání dat pro úvodní statistiku.
      $this->setStatsData();

      // Odkaz na nápovědu.
      $this->setHelpLink('');
    }


    /**
     * Získá data pro statistiku a grafy.
     */
    private function setStatsData() {
      // Počet všech bezpečnostních incidentů.
      $countIncidents = IncidentModel::getIncidentsCount();
      $this->setViewData('countIncidents', get_formatted_number($countIncidents));

      // Počet vyřešených incidentů.
      $countResolvedIncidents = IncidentModel::getIncidentsCount('resolved');
      $this->setViewData('countResolvedIncidents', get_formatted_number($countResolvedIncidents));

      // Počet nevyřešených incidentů.
      $countUnresolvedIncidents = IncidentModel::getIncidentsCount('unresolved');
      $this->setViewData('countUnresolvedIncidents', get_formatted_number($countUnresolvedIncidents));

      // Počet lokálních správců.
      $countDeptContacts = DeptContactsModel::getDeptContactsCount();
      $this->setViewData('countDeptContacts', get_formatted_number($countDeptContacts));

      // Legenda a barvy pro koláčový graf se aktuálními stavy incidentů.
      $this->setViewData('pieChartIncStatuses', StatsModel::getIncidentStatusesChart());

      // Legenda a barvy pro koláčový graf s typy incidentů.
      $this->setViewData('pieChartIncTypes', StatsModel::getIncidentTypesChart());

      // Data pro sloupcový graf.
      $this->setViewData('barChartAxisX', StatsModel::getMonthsNames());
      $this->setViewData('barChartDatasets', StatsModel::getIncidentsTypesByYear(date('Y')));
    }
  }
